@@ -18,21 +18,21 @@ extern "C" {
  *
  * the version string like "1.2.3"
  */
-#define LIBEXSLT_DOTTED_VERSION "1.0.10"
+#define LIBEXSLT_DOTTED_VERSION "1.0.11"
 
 /**
  * LIBEXSLT_VERSION:
  *
  * the version number: 1.2.3 value is 1002003
  */
-#define LIBEXSLT_VERSION 703
+#define LIBEXSLT_VERSION 704
 
 /**
  * LIBEXSLT_VERSION_STRING:
  *
  * the version number string, 1.2.3 value is "1002003"
  */
-#define LIBEXSLT_VERSION_STRING "703"
+#define LIBEXSLT_VERSION_STRING "704"
 
 /**
  * ATTRIBUTE_UNUSED:
@@ -60,7 +60,7 @@ extern "C" {
  * against this library.
  */
 #if !defined LIBEXSLT_PUBLIC
-#if defined _MSC_VER && !defined IN_LIBEXSLT && !defined LIBEXSLT_STATIC
+#if (defined (__CYGWIN__) || defined _MSC_VER) && !defined IN_LIBEXSLT && !defined LIBEXSLT_STATIC
 #define LIBEXSLT_PUBLIC __declspec(dllimport)
 #else
 #define LIBEXSLT_PUBLIC 
