@@ -3,7 +3,7 @@
  *
  * See Copyright for the status of this software.
  *
- * Daniel.Veillard@imag.fr
+ * daniel@veillard.com
  * Bjorn Reese <breese@users.sourceforge.net>
  */
 
@@ -27,6 +27,7 @@ typedef struct _xsltNumberData {
     xmlChar *from;
     xmlChar *value;
     xmlChar *format;
+    int has_format;
     int digitsPerGroup;
     xmlChar groupingCharacter;
     xmlDocPtr doc;
