@@ -861,7 +861,7 @@ xsltParseStylesheetPreserveSpace(xsltStylesheetPtr style, xmlNodePtr cur) {
 /**
  * xsltParseStylesheetExtPrefix:
  * @style:  the XSLT stylesheet
- * @template:  the "strip-space" prefix
+ * @template:  the "extension-element-prefixes" prefix
  *
  * parse an XSLT stylesheet extension prefix and record
  * prefixes needing stripping
@@ -1499,10 +1499,11 @@ xsltParseStylesheetKey(xsltStylesheetPtr style, xmlNodePtr key) {
     }
 
     /*
-     * register the key
+     * register the keys
      */
     xsltAddKey(style, name, nameURI, match, use, key);
 
+
 error:
     if (use != NULL)
 	xmlFree(use);
@@ -1570,6 +1571,8 @@ xsltParseStylesheetTemplate(xsltStylesheetPtr style, xmlNodePtr template) {
 	    if (URI != NULL)
 		modeURI = xmlStrdup(URI);
 	}
+	ret->mode = mode;
+	ret->modeURI = modeURI;
 #ifdef WITH_XSLT_DEBUG_PARSING
 	xsltGenericDebug(xsltGenericDebugContext,
 	     "xsltParseStylesheetTemplate: mode %s\n", mode);
@@ -1624,10 +1627,6 @@ xsltParseStylesheetTemplate(xsltStylesheetPtr style, xmlNodePtr template) {
 error:
     for (;exclPrefixes > 0;exclPrefixes--)
 	exclPrefixPop(style);
-    if (mode != NULL)
-	xmlFree(mode);
-    if (modeURI != NULL)
-	xmlFree(modeURI);
 }
 
 /**
@@ -1693,6 +1692,16 @@ xsltParseStylesheetTop(xsltStylesheetPtr style, xmlNodePtr top) {
 	    cur = cur->next;
 	    continue;
 	}
+	if (cur->type == XML_TEXT_NODE) {
+	    if (cur->content != NULL) {
+		xsltPrintErrorContext(NULL, style, cur);
+		xsltGenericError(xsltGenericErrorContext,
+		    "misplaced text element: '%s'\n", cur->content);
+	    }
+	    style->errors++;
+            cur = cur->next;
+	    continue;
+	}
 	if ((cur->type == XML_ELEMENT_NODE) && (cur->ns == NULL)) {
 	    xsltGenericError(xsltGenericErrorContext,
 		     "Found a top-level element %s with null namespace URI\n",
@@ -1701,7 +1710,7 @@ xsltParseStylesheetTop(xsltStylesheetPtr style, xmlNodePtr top) {
 	    cur = cur->next;
 	    continue;
 	}
-	if (!(IS_XSLT_ELEM(cur))) {
+	if ((cur->type == XML_ELEMENT_NODE) && (!(IS_XSLT_ELEM(cur)))) {
 	    xsltTopLevelFunction function;
 
 	    function = xsltExtModuleTopLevelLookup(cur->name,
