@@ -18,21 +18,21 @@ extern "C" {
  *
  * the version string like "1.2.3"
  */
-#define LIBXSLT_DOTTED_VERSION "1.0.9"
+#define LIBXSLT_DOTTED_VERSION "1.0.11"
 
 /**
  * LIBXSLT_VERSION:
  *
  * the version number: 1.2.3 value is 1002003
  */
-#define LIBXSLT_VERSION 10009
+#define LIBXSLT_VERSION 10011
 
 /**
  * LIBXSLT_VERSION_STRING:
  *
  * the version number string, 1.2.3 value is "1002003"
  */
-#define LIBXSLT_VERSION_STRING "10009"
+#define LIBXSLT_VERSION_STRING "10011"
 
 /**
  * WITH_XSLT_DEBUG:
@@ -95,11 +95,15 @@ extern "C" {
 /**
  * LIBXSLT_PUBLIC:
  *
- * This macro is used to declare PUBLIC variables for MSC on Windows
+ * This macro is used to declare PUBLIC variables for Cygwin and for MSC on Windows
  */
-#if !defined(WIN32) || defined(__CYGWIN__)
+#if !defined LIBXSLT_PUBLIC
+#if (defined(__CYGWIN__) || defined _MSC_VER) && !defined IN_LIBXSLT && !defined LIBXSLT_STATIC
+#define LIBXSLT_PUBLIC __declspec(dllimport)
+#else
 #define LIBXSLT_PUBLIC
 #endif
+#endif
 
 #ifdef __cplusplus
 }
